==> open-cluster-management-observability-model-5.12.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/shared/ConditionBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConditionBuilder extends io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ConditionFluentImpl<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.Condition,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ConditionBuilder>{
  public ConditionBuilder() {
    this(false);
  }
  public ConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new Condition(), validationEnabled);
  }
  public ConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public ConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Condition(), validationEnabled);
  }
  public ConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ConditionFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.Condition instance) {
    this(fluent, instance, false);
  }
  public ConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ConditionFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.Condition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public ConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.Condition instance) {
    this(instance,false);
  }
  public ConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.Condition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.Condition build() {
    Condition buildable = new Condition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getObservedGeneration(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConditionBuilder that = (ConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-observability-model-6.5.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/shared/ConditionBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConditionBuilder extends ConditionFluentImpl<ConditionBuilder> implements VisitableBuilder<Condition,ConditionBuilder>{
  public ConditionBuilder() {
    this(false);
  }
  public ConditionBuilder(Boolean validationEnabled) {
    this(new Condition(), validationEnabled);
  }
  public ConditionBuilder(ConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public ConditionBuilder(ConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Condition(), validationEnabled);
  }
  public ConditionBuilder(ConditionFluent<?> fluent,Condition instance) {
    this(fluent, instance, false);
  }
  public ConditionBuilder(ConditionFluent<?> fluent,Condition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public ConditionBuilder(Condition instance) {
    this(instance,false);
  }
  public ConditionBuilder(Condition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  ConditionFluent<?> fluent;
  Boolean validationEnabled;
  public Condition build() {
    Condition buildable = new Condition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getObservedGeneration(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  
}
